/****************************************************************************
** Meta object code from reading C++ file 'KReportDesigner.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kreport-3.0.2/src/wrtembed/KReportDesigner.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'KReportDesigner.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KReportDesigner_t {
    QByteArrayData data[25];
    char stringdata0[331];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KReportDesigner_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KReportDesigner_t qt_meta_stringdata_KReportDesigner = {
    {
QT_MOC_LITERAL(0, 0, 15), // "KReportDesigner"
QT_MOC_LITERAL(1, 16, 19), // "pagePropertyChanged"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 13), // "KPropertySet&"
QT_MOC_LITERAL(4, 51, 1), // "s"
QT_MOC_LITERAL(5, 53, 18), // "propertySetChanged"
QT_MOC_LITERAL(6, 72, 5), // "dirty"
QT_MOC_LITERAL(7, 78, 17), // "reportDataChanged"
QT_MOC_LITERAL(8, 96, 12), // "itemInserted"
QT_MOC_LITERAL(9, 109, 6), // "entity"
QT_MOC_LITERAL(10, 116, 14), // "slotEditDelete"
QT_MOC_LITERAL(11, 131, 11), // "slotEditCut"
QT_MOC_LITERAL(12, 143, 12), // "slotEditCopy"
QT_MOC_LITERAL(13, 156, 13), // "slotEditPaste"
QT_MOC_LITERAL(14, 170, 15), // "QGraphicsScene*"
QT_MOC_LITERAL(15, 186, 8), // "slotItem"
QT_MOC_LITERAL(16, 195, 17), // "slotSectionEditor"
QT_MOC_LITERAL(17, 213, 17), // "slotRaiseSelected"
QT_MOC_LITERAL(18, 231, 17), // "slotLowerSelected"
QT_MOC_LITERAL(19, 249, 19), // "slotPropertyChanged"
QT_MOC_LITERAL(20, 269, 10), // "KProperty&"
QT_MOC_LITERAL(21, 280, 1), // "p"
QT_MOC_LITERAL(22, 282, 22), // "slotPageButton_Pressed"
QT_MOC_LITERAL(23, 305, 17), // "slotItemTriggered"
QT_MOC_LITERAL(24, 323, 7) // "checked"

    },
    "KReportDesigner\0pagePropertyChanged\0"
    "\0KPropertySet&\0s\0propertySetChanged\0"
    "dirty\0reportDataChanged\0itemInserted\0"
    "entity\0slotEditDelete\0slotEditCut\0"
    "slotEditCopy\0slotEditPaste\0QGraphicsScene*\0"
    "slotItem\0slotSectionEditor\0slotRaiseSelected\0"
    "slotLowerSelected\0slotPropertyChanged\0"
    "KProperty&\0p\0slotPageButton_Pressed\0"
    "slotItemTriggered\0checked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KReportDesigner[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   99,    2, 0x06 /* Public */,
       5,    0,  102,    2, 0x06 /* Public */,
       6,    0,  103,    2, 0x06 /* Public */,
       7,    0,  104,    2, 0x06 /* Public */,
       8,    1,  105,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      10,    0,  108,    2, 0x0a /* Public */,
      11,    0,  109,    2, 0x0a /* Public */,
      12,    0,  110,    2, 0x0a /* Public */,
      13,    0,  111,    2, 0x0a /* Public */,
      13,    1,  112,    2, 0x0a /* Public */,
      15,    1,  115,    2, 0x0a /* Public */,
      16,    0,  118,    2, 0x0a /* Public */,
      17,    0,  119,    2, 0x0a /* Public */,
      18,    0,  120,    2, 0x0a /* Public */,
      19,    2,  121,    2, 0x08 /* Private */,
      22,    0,  126,    2, 0x08 /* Private */,
      23,    1,  127,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    9,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 14,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 20,    4,   21,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   24,

       0        // eod
};

void KReportDesigner::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KReportDesigner *_t = static_cast<KReportDesigner *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->pagePropertyChanged((*reinterpret_cast< KPropertySet(*)>(_a[1]))); break;
        case 1: _t->propertySetChanged(); break;
        case 2: _t->dirty(); break;
        case 3: _t->reportDataChanged(); break;
        case 4: _t->itemInserted((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->slotEditDelete(); break;
        case 6: _t->slotEditCut(); break;
        case 7: _t->slotEditCopy(); break;
        case 8: _t->slotEditPaste(); break;
        case 9: _t->slotEditPaste((*reinterpret_cast< QGraphicsScene*(*)>(_a[1]))); break;
        case 10: _t->slotItem((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 11: _t->slotSectionEditor(); break;
        case 12: _t->slotRaiseSelected(); break;
        case 13: _t->slotLowerSelected(); break;
        case 14: _t->slotPropertyChanged((*reinterpret_cast< KPropertySet(*)>(_a[1])),(*reinterpret_cast< KProperty(*)>(_a[2]))); break;
        case 15: _t->slotPageButton_Pressed(); break;
        case 16: _t->slotItemTriggered((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KReportDesigner::*_t)(KPropertySet & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KReportDesigner::pagePropertyChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KReportDesigner::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KReportDesigner::propertySetChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KReportDesigner::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KReportDesigner::dirty)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (KReportDesigner::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KReportDesigner::reportDataChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (KReportDesigner::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KReportDesigner::itemInserted)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject KReportDesigner::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KReportDesigner.data,
      qt_meta_data_KReportDesigner,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KReportDesigner::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KReportDesigner::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KReportDesigner.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KReportDesigner::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void KReportDesigner::pagePropertyChanged(KPropertySet & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KReportDesigner::propertySetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KReportDesigner::dirty()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KReportDesigner::reportDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KReportDesigner::itemInserted(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
